Parameters
==========
.. currentmodule:: puq
.. autoclass:: Parameter
	:members:
.. autoclass:: CustomParameter
	:members:
.. autoclass:: ExponParameter
	:members:
.. autoclass:: NormalParameter
	:members:
.. autoclass:: RayleighParameter
	:members:
.. autoclass:: UniformParameter
	:members:
.. autoclass:: WeibullParameter
	:members:
.. autoclass:: PSweep
   :members:
